module DownloadHelper

  def within_file_size_threshold?(total_size)
    total_size > 0 && total_size < ENV.fetch('DOWNLOAD_FILES_SIZE_LIMIT', '100000000').to_i
  end

  def within_file_count_threshold?(file_count)
    file_count > 0 && file_count < ENV.fetch('DOWNLOAD_FILES_COUNT_LIMIT', '150').to_i
  end

  def objects_size_and_file_format
    s3 = S3StorageService.new()
    s3.init_client
    bucket_id = s3.sanitise_name(work.id)
    list_of_objects, total_size = s3.list_all_objects(bucket_id)
    if within_file_size_threshold?(total_size) &&
      within_file_count_threshold?(list_of_objects.size)
      format = 'zip'
    else
      format = 'shell'
    end
    return list_of_objects, total_size, format
  end

  def has_zip_file?
    if work.date_modified.present?
      File.exists?(zip_file_path) and local_file_last_modified > work.date_modified
    else
      File.exists?(zip_file_path)
    end
  end

  def has_shell_file?
    file_path = shell_file_path
    File.exists?(file_path) and not shell_file_expired?(file_path)
  end

  # def file_exist?(file_path)
  #   File.exists?(file_path)
  # end
  #
  def shell_file_expired?(file_path)
    if work.date_modified.present?
      File.ctime(file_path).to_datetime <= (DateTime.now - 1.day) or
        local_file_last_modified <= work.date_modified
    else
      File.ctime(file_path).to_datetime <= (DateTime.now - 1.day)
    end
  end

  def base_download_dir
    File.join(ENV.fetch('DOWNLOAD_PATH', '/shared/downloads'), work.id)
  end

  def zip_file_path
    File.join(ENV.fetch('DOWNLOAD_PATH', "/shared/downloads"), "#{work.id}.zip")
  end

  def shell_file_path
    File.join(ENV.fetch('DOWNLOAD_PATH', "/shared/downloads"), "#{work.id}.sh")
  end

  def cleanup_path(file_path)
    FileUtils.rm_rf(file_path)
  end

end
