require 'rails_helper'
include Warden::Test::Helpers

RSpec.feature 'Create Collection', js: false do
  context 'a logged in user' do
    let(:user_attributes) do
      { email: 'test@example.com' }
    end
    let(:user) do
      User.new(user_attributes) { |u| u.save(validate: false) }
    end
  
    let(:admin_set_id) { Hyrax::AdminSetCreateService.find_or_create_default_admin_set.id.to_s }
    let(:permission_template) { Hyrax::PermissionTemplate.find_or_create_by!(source_id: admin_set_id) }
    let(:workflow) { Sipity::Workflow.create!(active: true, name: 'test-workflow', permission_template: permission_template) }
    let(:collection_type) {Hyrax::CollectionType.find_or_create_by(title: 'CRC 1280')}
    let(:parent_collection) {Collection.create(title: ['CRC 1280'], collection_type_gid: collection_type.gid)}

    before do
      # Create a single action that can be taken
      Sipity::WorkflowAction.create!(name: 'submit', workflow: workflow)

      # Grant the user access to deposit into the admin set.
      Hyrax::PermissionTemplateAccess.create!(
        permission_template_id: permission_template.id,
        agent_type: 'user',
        agent_id: user.user_key,
        access: 'manage'
      )
      login_as user
    end

    scenario 'create and delete collection Group with roles', js: false do
      visit "/dashboard/collections/new?collection_type_id=#{collection_type.id}&crc_collection_type=group&locale=en&parent_id=#{parent_collection.id}" 
      fill_in('collection_title_', with: 'My Demo Collection')

      click_on('Save')

      sleep 5

      created_collection = Collection.where(title: 'My Demo Collection').first
      expect(created_collection.manager_role_for_group.name).to eq("#{collection_type.title.parameterize(separator: '_')}_#{created_collection.id}_manager")
      expect(created_collection.member_role_for_group.name).to eq("#{collection_type.title.parameterize(separator: '_')}_#{created_collection.id}_member")

      created_collection.destroy

      expect(created_collection.manager_role_for_group).to eq(nil)
      expect(created_collection.member_role_for_group).to eq(nil)
    end
  end
end